summaryrefslogtreecommitdiffstats
path: root/tdecore/kcmdlineargs.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:21:02 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:21:02 -0600
commit8e7816b2f9f62a2df094c5b2a7aa5abb6bc1226a (patch)
tree19ff5ecf5e6b5168e5503677f18b85f3dfa91f95 /tdecore/kcmdlineargs.cpp
parent5bca2e3e42d02f8fed9ffc399ea14f8a05694cb0 (diff)
downloadtdelibs-8e7816b2f9f62a2df094c5b2a7aa5abb6bc1226a.tar.gz
tdelibs-8e7816b2f9f62a2df094c5b2a7aa5abb6bc1226a.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/kcmdlineargs.cpp')
-rw-r--r--tdecore/kcmdlineargs.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdecore/kcmdlineargs.cpp b/tdecore/kcmdlineargs.cpp
index 6550f9144..d9e564d4a 100644
--- a/tdecore/kcmdlineargs.cpp
+++ b/tdecore/kcmdlineargs.cpp
@@ -188,7 +188,7 @@ TDECmdLineArgs::init(int _argc, char **_argv, const KAboutData *_about, bool noK
win32_slashify(mCwd, PATH_MAX);
#endif
if (!noKApp)
- KApplication::addCmdLineOptions();
+ TDEApplication::addCmdLineOptions();
}
TQString TDECmdLineArgs::cwd()
@@ -671,7 +671,7 @@ TDECmdLineArgs::parseAllArgs()
}
/**
* For KApplication only:
*
* Return argc
*/
@@ -679,7 +679,7 @@ int *
TDECmdLineArgs::tqt_argc()
{
if (!argsList)
- KApplication::addCmdLineOptions(); // Lazy bastards!
+ TDEApplication::addCmdLineOptions(); // Lazy bastards!
static int tqt_argc = -1;
if( tqt_argc != -1 )
@@ -702,7 +702,7 @@ TDECmdLineArgs::tqt_argc()
}
/**
* For KApplication only:
*
* Return argv
*/
@@ -710,7 +710,7 @@ char ***
TDECmdLineArgs::tqt_argv()
{
if (!argsList)
- KApplication::addCmdLineOptions(); // Lazy bastards!
+ TDEApplication::addCmdLineOptions(); // Lazy bastards!
static char** tqt_argv;
if( tqt_argv != NULL )
@@ -671,7 +671,7 @@ TDECmdLineArgs::parseAllArgs()
}
/**
- * For KApplication only:
+ * For TDEApplication only:
*
* Return argc
@@ -702,7 +702,7 @@ TDECmdLineArgs::tqt_argc()
}
/**
- * For KApplication only:
+ * For TDEApplication only:
*
* Return argv